AutodiffComposition
===================

.. container:: related

    *Related*

    * `Composition_Learning`
    * `Composition_Bias_Nodes`

.. automodule:: psyneulink.library.compositions.autodiffcomposition
   :members: AutodiffComposition, copy_torch_param_to_projection_matrix
   :private-members:
   :exclude-members:  Parameters, show_structure, parameters, AutodiffCompositionError, PytorchCompositionWrapper, _update_results, _get_execution_mode, _get_pytorch_backprop_pathway, _add_dependency, _build_pytorch_representation, autodiff_forward, do_gradient_optimization, autodiff_backward, _get_autodiff_inputs_values, _get_autodiff_targets_values, _parse_learning_spec, _identify_target_nodes, _get_execution_mode, _update_results, assign_ShowGraph